@@ -1,17 +1,13 @@
-import os
 import click
-import subprocess
-import sys
 import logging
 
 from . import image, policy, evaluate, subscription, registry, system, utils, repo, event, query, account, archives
 
 from anchorecli import version
-import anchorecli.clients
+import anchorecli.clients # noqa
 
-#from anchoreservice.subsys import logger
 
-@click.group()
+@click.group(context_settings=dict(help_option_names=['-h', '--help', 'help']))
 @click.option('--debug', is_flag=True, help='Debug output to stderr')
 @click.option('--u', help='Username (or use environment variable ANCHORE_CLI_USER)')
 @click.option('--p', help='Password (or use environment variable ANCHORE_CLI_PASS)')
@@ -23,7 +19,6 @@ import anchorecli.clients
 @click.option('--as-account', help='Set account context for the command to another account than the one the user belongs to. Subject to authz', default=None)
 @click.version_option(version=version.version)
 @click.pass_context
-#@extended_help_option(extended_help="extended help")
 def main_entry(ctx, debug, u, p, url, hub_url, api_version, insecure, json, as_account):
     if debug:
         logging.basicConfig(level=logging.DEBUG)
@@ -43,9 +38,27 @@ def main_entry(ctx, debug, u, p, url, hub_url, api_version, insecure, json, as_a
     config = utils.setup_config(cli_opts)
     if config['debug']:
         logging.basicConfig(level=logging.DEBUG)
-        
+
     ctx.obj = config
 
+
+class Help(click.Command):
+    """
+    Do not parse any arguments, allow any args past the `help` command,
+    always return the help output
+    """
+
+    def parse_args(self, ctx, args):
+        return []
+
+
+@click.command(cls=Help)
+@click.pass_context
+def help(ctx):
+    print(ctx.parent.get_help())
+
+
+main_entry.add_command(help)
 main_entry.add_command(image.image)
 main_entry.add_command(evaluate.evaluate)
 main_entry.add_command(policy.policy)
