@@ -44,7 +44,7 @@ def wait(input_image, timeout, interval):
         #timeout = float(timeout)
         t1 = time.time()
         while timeout < 0 or time.time() - t1 < timeout:
-            _logger.debug("discovery from input: " + str(itype) + " : " + str(image))
+            _logger.debug("discovery from input: %s : %s",  str(itype), str(image))
             if itype == 'tag':
                 ret = anchorecli.clients.apiexternal.get_image(config, tag=image, history=False)
             elif itype == 'imageid':
@@ -176,7 +176,7 @@ def get(input_image, show_history):
         itype = anchorecli.cli.utils.discover_inputimage_format(config, input_image)
         image = input_image
 
-        _logger.debug("discovery from input: " + str(itype) + " : " + str(image))
+        _logger.debug("discovery from input: %s : %s", str(itype), str(image))
         if itype == 'tag':
             ret = anchorecli.clients.apiexternal.get_image(config, tag=image, history=show_history)
         elif itype == 'imageid':
@@ -245,7 +245,7 @@ def query_content(input_image, content_type):
 
     try:
         itype, image, imageDigest = anchorecli.cli.utils.discover_inputimage(config, input_image)
-        _logger.debug("discovery from input: " + str(itype) + " : " + str(image) + " : " + str(imageDigest))
+        _logger.debug("discovery from input: %s : %s : %s",  str(itype), str(image), str(imageDigest))
 
         if not imageDigest:
             ecode = 1
@@ -255,7 +255,10 @@ def query_content(input_image, content_type):
             ecode = anchorecli.cli.utils.get_ecode(ret)
             if ret:
                 if ret['success']:
-                    print(anchorecli.cli.utils.format_output(config, 'image_content', {'query_type':content_type}, ret['payload']))
+                    output = anchorecli.cli.utils.format_output(config, 'image_content', {'query_type':content_type}, ret['payload'])
+                    if not output:
+                        raise Exception('There is no image content (%s) to provide for %s' % (content_type, input_image))
+                    print(output)
                 else:
                     raise Exception (json.dumps(ret['error'], indent=4))
             else:
@@ -282,7 +285,7 @@ def query_metadata(input_image, metadata_type):
 
     try:
         itype, image, imageDigest = anchorecli.cli.utils.discover_inputimage(config, input_image)
-        _logger.debug("discovery from input: " + str(itype) + " : " + str(image) + " : " + str(imageDigest))
+        _logger.debug("discovery from input: %s : %s : %s", str(itype), str(image), str(imageDigest))
 
         if not imageDigest:
             ecode = 1
@@ -309,6 +312,7 @@ def query_metadata(input_image, metadata_type):
 
     anchorecli.cli.utils.doexit(ecode)
 
+
 @image.command(name='vuln', short_help="Get image vulnerabilities")
 @click.argument('input_image', nargs=1)
 @click.argument('vuln_type', nargs=1, required=False)
@@ -331,12 +335,15 @@ def query_vuln(input_image, vuln_type, vendor_only):
         else:
             ret = anchorecli.clients.apiexternal.query_image(config, imageDigest=imageDigest, query_group='vuln', query_type=vuln_type, vendor_only=vendor_only)
             ecode = anchorecli.cli.utils.get_ecode(ret)
-
             if ret:
                 if ret['success']:
-                    print(anchorecli.cli.utils.format_output(config, 'image_vuln', {'query_type':vuln_type}, ret['payload']))
+                    print(anchorecli.cli.utils.format_output(config, 'image_vuln', {'query_type': vuln_type}, ret['payload']))
                 else:
-                    raise Exception (json.dumps(ret['error'], indent=4))
+                    if 'analysis_status: analyzing' in ret['error']['message']:
+                        ecode = 100
+                    elif 'analysis_status: not_analyzed' in ret['error']['message']:
+                        ecode = 101
+                    raise Exception(json.dumps(ret['error'], indent=4))
             else:
                 raise Exception("operation failed with empty response")
 
@@ -344,9 +351,9 @@ def query_vuln(input_image, vuln_type, vendor_only):
         print(anchorecli.cli.utils.format_error_output(config, 'image_vuln', {}, err))
         if not ecode:
             ecode = 2
-
     anchorecli.cli.utils.doexit(ecode)
 
+
 @image.command(name='del', short_help="Delete an image")
 @click.argument('input_image', required=False)
 @click.option('--force', is_flag=True, help="Force deletion of image by cancelling any subscription/notification settings prior to image delete")
