@@ -123,14 +123,15 @@ def setup_config(cli_opts):
 
 
 def doexit(ecode):
-    try:
-        sys.stdout.close()
-    except Exception:
-        pass
-    try:
-        sys.stderr.close()
-    except Exception:
-        pass
+    if not os.environ.get('ANCHORE_CLI_NO_FDS_CLEANUP'):
+        try:
+            sys.stdout.close()
+        except Exception:
+            pass
+        try:
+            sys.stderr.close()
+        except Exception:
+            pass
     sys.exit(ecode)
 
 
@@ -298,10 +299,11 @@ def format_output(config, op, params, payload):
                 obuf = obuf + "\n"
             else:
                 if params['query_type'] == 'os':
-                    header = ['Package', 'Version', 'License']
+                    header = ['Package', 'Version', 'Licenses']
                     t = plain_column_table(header)
                     for el in payload['content']:
-                        row = [el['package'], el['version'], el['license']]
+                        licenses = el.get('licenses', [el.get('license')])
+                        row = [el['package'], el['version'], " ".join(licenses)]
                         t.add_row(row)
                     obuf = obuf + t.get_string(sortby='Package')
                 elif params['query_type'] == 'files':
@@ -326,10 +328,7 @@ def format_output(config, op, params, payload):
                         t.add_row(row)
                     obuf = obuf + t.get_string(sortby='Package')
                 elif params['query_type'] in ['manifest', 'dockerfile', 'docker_history']:
-                    try:
-                        obuf = base64.b64decode(payload.get('metadata', "")).decode('utf-8')
-                    except Exception:
-                        obuf = ""
+                    obuf = format_content_query(payload)
                 else:
                     try:
                         if payload['content']:
@@ -933,6 +932,22 @@ def format_vulnerabilities(payload, params):
     return obuf
 
 
+def format_content_query(payload):
+    content = payload.get('content', '')
+    if not content:
+        return ''
+    if isinstance(content, list):
+        # In some situations the `content` key can be a list, not a string
+        content = ''.join(content)
+    try:
+        return base64.b64decode(content).decode('utf-8')
+    except Exception:
+        # This broad exception catching is warranted here because there are all
+        # sort of warts we would need to catch with utf-8 decoding and
+        # b64decode. The actual exception is not that relevant here
+        return ''
+
+
 def string_splitter(input_str, max_length=40):
     """
     Returns a string that is the input string but with \n inserted every max_length chars
@@ -1047,7 +1062,7 @@ def get_ecode(response):
     ecode = 2
     try:
         httpcode = response['httpcode']
-        _logger.debug("fetched httpcode from response: " + str(httpcode))
+        _logger.debug("fetched httpcode from response: %s", str(httpcode))
         if httpcode in range(200, 299):
             ecode = 0
         elif httpcode in [401, 500]:
